# iciba-cli

A cli query tool for iciba.com (金山词霸)

## Screenshots

- Search word with prompt (powered by `prompt_toolkit`)

![prompt](https://raw.githubusercontent.com/lihe07/iciba/main/images/1.png)

- Rich text results (powered by `rich`)

![rich](https://raw.githubusercontent.com/lihe07/iciba/main/images/2.png)


## Installation

Requirments: `python >= 3.7.0` (required by rich)

`pip install iciba`

## Usage

- Query a word

  `iciba <word>`

- Interactively query a word (with prompt)

  `iciba`


